==> spring-boot-ext-1.2.149-sources.jar: cn/com/duibaboot/ext/autoconfigure/cat/SleuthMybatisPlugin.java <==
package cn.com.duibaboot.ext.autoconfigure.cat;

import org.apache.ibatis.executor.Executor;
import org.apache.ibatis.mapping.BoundSql;
import org.apache.ibatis.mapping.MappedStatement;
import org.apache.ibatis.mapping.ParameterMapping;
import org.apache.ibatis.mapping.SqlCommandType;
import org.apache.ibatis.plugin.*;
import org.apache.ibatis.reflection.MetaObject;
import org.apache.ibatis.session.Configuration;
import org.apache.ibatis.session.ResultHandler;
import org.apache.ibatis.session.RowBounds;
import org.apache.ibatis.type.TypeHandlerRegistry;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.sleuth.ErrorParser;
import org.springframework.cloud.sleuth.Span;
import org.springframework.cloud.sleuth.Tracer;

import java.text.DateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.Properties;

/**
 * 对MyBatis进行拦截，添加Sleuth监控
 * 
 * @author huangwq
 */
@Intercepts({
    @Signature(method = "query", type = Executor.class, args = {  
            MappedStatement.class, Object.class, RowBounds.class,  
            ResultHandler.class }),
    @Signature(method = "update", type = Executor.class, args = { MappedStatement.class, Object.class }) 
})
public class SleuthMybatisPlugin implements Interceptor{

    @Autowired
    private Tracer tracer;
    @Autowired
    private ErrorParser errorParser;

	@Override
	public Object intercept(Invocation invocation) throws Throwable {
	    if(!tracer.isTracing() || !tracer.getCurrentSpan().isExportable()){
	        return invocation.proceed();
        }

        MappedStatement mappedStatement = (MappedStatement) invocation.getArgs()[0];
        //得到 类名-方法
        String[] strArr = mappedStatement.getId().split("\\.");
        String class_method = strArr[strArr.length-2] + "." + strArr[strArr.length-1];

        Span span = tracer.createSpan("sql:/"+class_method);
        Object result;
        try {
//        System.out.println("class_method = "+ class_method);
            //得到sql语句
//        Object parameter = null;
//        if(invocation.getArgs().length > 1){
//            parameter = invocation.getArgs()[1];
//        }
//        BoundSql boundSql = mappedStatement.getBoundSql(parameter);
//        Configuration configuration = mappedStatement.getConfiguration();
//        String sql = showSql(configuration, boundSql);
//        System.out.println("sql = "+ sql);

            //获取SQL类型
            SqlCommandType sqlCommandType = mappedStatement.getSqlCommandType();
            String method = sqlCommandType.name().toLowerCase();

            span.tag("sql.method", method);//INSERT/UPDATE/...
            span.tag("sql.class_method", class_method);
            span.tag(Span.SPAN_LOCAL_COMPONENT_TAG_NAME, "mybatis");//本地组件名
            span.tag(Span.SPAN_PEER_SERVICE_TAG_NAME, "MySQL");//远程服务名
//            span.tag("peer.host", "www.duiba.com.cn:3306");//远程host
//            this.tracer.addTag("sql.sql", sql);
//            this.tracer.addTag("sql.sql", parameter);
            span.logEvent(Span.CLIENT_SEND);

            result = invocation.proceed();
        } catch(Exception e){
            errorParser.parseErrorTags(span, e);
            throw e;
        } finally {
            span.logEvent(Span.CLIENT_RECV);
            this.tracer.close(span);
        }

        return result;
	}
	
	public String showSql(Configuration configuration, BoundSql boundSql) {
        Object parameterObject = boundSql.getParameterObject();
        List<ParameterMapping> parameterMappings = boundSql.getParameterMappings();
        String sql = boundSql.getSql().replaceAll("[\\s]+", " ");
        if (parameterMappings.size() > 0 && parameterObject != null) {
            TypeHandlerRegistry typeHandlerRegistry = configuration.getTypeHandlerRegistry();
            if (typeHandlerRegistry.hasTypeHandler(parameterObject.getClass())) {
                sql = sql.replaceFirst("\\?", getParameterValue(parameterObject));
 
            } else {
                MetaObject metaObject = configuration.newMetaObject(parameterObject);
                for (ParameterMapping parameterMapping : parameterMappings) {
                    String propertyName = parameterMapping.getProperty();
                    if (metaObject.hasGetter(propertyName)) {
                        Object obj = metaObject.getValue(propertyName);
                        sql = sql.replaceFirst("\\?", getParameterValue(obj));
                    } else if (boundSql.hasAdditionalParameter(propertyName)) {
                        Object obj = boundSql.getAdditionalParameter(propertyName);
                        sql = sql.replaceFirst("\\?", getParameterValue(obj));
                    }
                }
            }
        }
        return sql;
    }
	
	private String getParameterValue(Object obj) {
        String value = null;
        if (obj instanceof String) {
            value = "'" + obj.toString() + "'";
        } else if (obj instanceof Date) {
            DateFormat formatter = DateFormat.getDateTimeInstance(DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.CHINA);
            value = "'" + formatter.format(new Date()) + "'";
        } else {
            if (obj != null) {
                value = obj.toString();
            } else {
                value = "";
            }
        }
        return value;
    }

	@Override
	public Object plugin(Object target) {
		return Plugin.wrap(target, this);
	}

	@Override
	public void setProperties(Properties arg0) {
	}

}

==> spring-boot-ext-1.2.221-sources.jar: cn/com/duibaboot/ext/autoconfigure/cat/SleuthMybatisPlugin.java <==
package cn.com.duibaboot.ext.autoconfigure.cat;

import org.apache.ibatis.executor.Executor;
import org.apache.ibatis.mapping.BoundSql;
import org.apache.ibatis.mapping.MappedStatement;
import org.apache.ibatis.mapping.ParameterMapping;
import org.apache.ibatis.mapping.SqlCommandType;
import org.apache.ibatis.plugin.*;
import org.apache.ibatis.reflection.MetaObject;
import org.apache.ibatis.session.Configuration;
import org.apache.ibatis.session.ResultHandler;
import org.apache.ibatis.session.RowBounds;
import org.apache.ibatis.type.TypeHandlerRegistry;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.sleuth.ErrorParser;
import org.springframework.cloud.sleuth.Span;
import org.springframework.cloud.sleuth.Tracer;

import java.text.DateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.Properties;

/**
 * 对MyBatis进行拦截，添加Sleuth监控
 * 
 * @author huangwq
 */
@Intercepts({
    @Signature(method = "query", type = Executor.class, args = {  
            MappedStatement.class, Object.class, RowBounds.class,  
            ResultHandler.class }),
    @Signature(method = "update", type = Executor.class, args = { MappedStatement.class, Object.class }) 
})
public class SleuthMybatisPlugin implements Interceptor{

    @Autowired
    private Tracer tracer;
    @Autowired
    private ErrorParser errorParser;

	@Override
	public Object intercept(Invocation invocation) throws Throwable {
	    if(!tracer.isTracing() || !tracer.getCurrentSpan().isExportable()){
	        return invocation.proceed();
        }

        MappedStatement mappedStatement = (MappedStatement) invocation.getArgs()[0];
        //得到 类名-方法
        String[] strArr = mappedStatement.getId().split("\\.");
        String classAndMethod = strArr[strArr.length-2] + "." + strArr[strArr.length-1];

        Span span = tracer.createSpan("sql:/"+classAndMethod);
        Object result;
        try {
//        System.out.println("class_method = "+ class_method);
            //得到sql语句
//        Object parameter = null;
//        if(invocation.getArgs().length > 1){
//            parameter = invocation.getArgs()[1];
//        }
//        BoundSql boundSql = mappedStatement.getBoundSql(parameter);
//        Configuration configuration = mappedStatement.getConfiguration();
//        String sql = showSql(configuration, boundSql);
//        System.out.println("sql = "+ sql);

            //获取SQL类型
            SqlCommandType sqlCommandType = mappedStatement.getSqlCommandType();
            String method = sqlCommandType.name().toLowerCase();

            span.tag("sql.method", method);//INSERT/UPDATE/...
            span.tag("sql.class_method", classAndMethod);
            span.tag(Span.SPAN_LOCAL_COMPONENT_TAG_NAME, "mybatis");//本地组件名
            span.tag(Span.SPAN_PEER_SERVICE_TAG_NAME, "MySQL");//远程服务名
//            span.tag("peer.host", "www.duiba.com.cn:3306");//远程host
//            this.tracer.addTag("sql.sql", sql);
//            this.tracer.addTag("sql.sql", parameter);
            span.logEvent(Span.CLIENT_SEND);

            result = invocation.proceed();
        } catch(Exception e){
            errorParser.parseErrorTags(span, e);
            throw e;
        } finally {
            span.logEvent(Span.CLIENT_RECV);
            this.tracer.close(span);
        }

        return result;
	}
	
	public String showSql(Configuration configuration, BoundSql boundSql) {
        Object parameterObject = boundSql.getParameterObject();
        List<ParameterMapping> parameterMappings = boundSql.getParameterMappings();
        String sql = boundSql.getSql().replaceAll("[\\s]+", " ");
        if (!parameterMappings.isEmpty() && parameterObject != null) {
            TypeHandlerRegistry typeHandlerRegistry = configuration.getTypeHandlerRegistry();
            if (typeHandlerRegistry.hasTypeHandler(parameterObject.getClass())) {
                sql = sql.replaceFirst("\\?", getParameterValue(parameterObject));
 
            } else {
                MetaObject metaObject = configuration.newMetaObject(parameterObject);
                for (ParameterMapping parameterMapping : parameterMappings) {
                    String propertyName = parameterMapping.getProperty();
                    if (metaObject.hasGetter(propertyName)) {
                        Object obj = metaObject.getValue(propertyName);
                        sql = sql.replaceFirst("\\?", getParameterValue(obj));
                    } else if (boundSql.hasAdditionalParameter(propertyName)) {
                        Object obj = boundSql.getAdditionalParameter(propertyName);
                        sql = sql.replaceFirst("\\?", getParameterValue(obj));
                    }
                }
            }
        }
        return sql;
    }
	
	private String getParameterValue(Object obj) {
        String value = null;
        if (obj instanceof String) {
            value = "'" + obj.toString() + "'";
        } else if (obj instanceof Date) {
            DateFormat formatter = DateFormat.getDateTimeInstance(DateFormat.DEFAULT, DateFormat.DEFAULT, Locale.CHINA);
            value = "'" + formatter.format(new Date()) + "'";
        } else {
            if (obj != null) {
                value = obj.toString();
            } else {
                value = "";
            }
        }
        return value;
    }

	@Override
	public Object plugin(Object target) {
		return Plugin.wrap(target, this);
	}

	@Override
	public void setProperties(Properties arg0) {
	    //do nothing
	}

}
